@@ -2,12 +2,11 @@ from typing import List
 from alpacka.functions import statistic_methods as s
 from alpacka.functions import presentation_functions as pf
 from configparser import ConfigParser
-import os.path
 
 
-class ncof_pipe:
+class ncof_pipeline:
 
-    def __init__(self, config_path:str):
+    def __init__(self, config_path: str):
         config = ConfigParser()
         path = config_path
         config.read(path)
@@ -24,7 +23,9 @@ class ncof_pipe:
 
         if config['NCOF']['Input_data_type'] not in self.Supported_inputs:
             raise TypeError(
-                f"Selected input data type ({config['NCOF']['Input_data_type']}) not currently supported as an input. \n Please format the input in on of the supported formats. \n Supported formats: {self.Supported_inputs}")
+                f"Selected input data type ({config['NCOF']['Input_data_type']}) not currently supported as an input. "
+                f"\n Please format the input in on of the supported formats. \n Supported formats: "
+                f"{self.Supported_inputs}")
         self.Input_data_type = config['NCOF']['Input_data_type']
 
     #### Check input data type ####
@@ -64,15 +65,16 @@ class ncof_pipe:
 
     #### Split score ####
     def split_score(self):
-        """splits the NCOF score into three categories based on the NCOF value for each element.
-        Returns the element indexes corresponding to the following three categories.
-        Inliers:      elements with NCOF score between mean +- 1 sigma,
-        Pos_outliers: elements with NCOF score greater than mean +1 sigma,
-        Neg_outliers: elements with NCOF score less than mean - 1 sigma.
-        The outliers are returned as a list of lists where index 0 is the 1-2 sigma outliers, index 1 is the 2-3 sigma outlers, and index 2 is 3-> outliers"""
+        """splits the NCOF score into three categories based on the NCOF value for each element. Returns the element
+        indexes corresponding to the following three categories. Inliers:      elements with NCOF score between mean
+        +- 1 sigma, Pos_outliers: elements with NCOF score greater than mean +1 sigma, Neg_outliers: elements with
+        NCOF score less than mean - 1 sigma. The outliers are returned as a list of lists where index 0 is the 1-2
+        sigma outliers, index 1 is the 2-3 sigma outlers, and index 2 is 3-> outliers """
         self.inliers, self.pos_outliers, self.neg_outliers = pf.sigma_splitter(self.score)
         if self.Verbose:
-            print(f" Inliers added under 'self.inliers' \n Positive outliers added under 'self.pos_outliers' \n Negative outliers added under 'self.neg_outliers' \n use self.get_--- to access the result")
+            print(
+                f" Inliers added under 'self.inliers' \n Positive outliers added under 'self.pos_outliers' \n "
+                f"Negative outliers added under 'self.neg_outliers' \n use self.get_--- to access the result")
 
     ####
     def get_inliers(self):
@@ -94,9 +96,9 @@ class ncof_pipe:
     #### indexes 2 words ####
     def ind_2_txt(self, list_of_list_of_list: list) -> List[List[List]]:
         """
-        Transforms a list of integer indexes to their corresponding words in the objects dictionary, Returns a list of list of words
-        @param list_of_list_of_list: List[List[List]]
-        @return: words_all: List[List[List]]
+        Transforms a list of integer indexes to their corresponding words in the objects dictionary, Returns a list
+        of list of words
+        @param list_of_list_of_list: List[List[List]] @return: words_all: List[List[List]]
         """
         words_all = []
         for list in list_of_list_of_list:
